

/* Linker Script for ARM
 * by Clemens Helfmeier
 * ClemensHelfmeier (at] gmx [dot} de
 *
 * Currently this linker script is a bit sub-optimal.
 */

ENTRY( _text_start )


/* Memory Definitions */

MEMORY
{
  FLASH		(rxw) : ORIGIN = 0x00000000, LENGTH = 64k
  SRAM		(rxw) : ORIGIN = 0x00200000, LENGTH = 16k
  SRAMEND	(w)  : ORIGIN = 0x00204000, LENGTH = 0
}


/* Section Definitions */
SECTIONS
{
	.text ( 0x000000 ) : AT( 0x00 ) {
		_text_start = . ;
		*(.rvectors)
		. = 32;
		* (.text)
		. = ALIGN( 4 );
		_text_end = . ;
	}>FLASH

/* and append all the read only data */
	.rodata : AT ( 0x00 + SIZEOF(.text) ) {
		_rodata_start = . ;
		* (.rodata*)
		. = ALIGN( 4 );
		_rodata_end = . ;
	} >FLASH

/* initialized data */
	. = ALIGN( 4 );
	PROVIDE( _data_load_start = . );
	.data : AT (0x00 + SIZEOF(.text) + SIZEOF(.rodata) ) {
		. = ALIGN( 4 );
		PROVIDE( _data_start = . );
		* (.data*)
		. = ALIGN( 4 );
		PROVIDE( _data_end = . );
	} >SRAM

/* uninitialized data to SRAM */
	.bss : {
		. = ALIGN( 4 );
		PROVIDE( _bss_start = . );
		* (.bss*)
		. = ALIGN( 4 );
		PROVIDE( _bss_end = . );
	} >SRAM

	.stack : {
		PROVIDE( _sram_end = . );
		PROVIDE( SRAM_END = _sram_end );
	} >SRAMEND

 /* Stabs debugging sections.  */
  .stab          0 : { *(.stab) }
  .stabstr       0 : { *(.stabstr) }
  .stab.excl     0 : { *(.stab.excl) }
  .stab.exclstr  0 : { *(.stab.exclstr) }
  .stab.index    0 : { *(.stab.index) }
  .stab.indexstr 0 : { *(.stab.indexstr) }
  .comment       0 : { *(.comment) }
  /* DWARF debug sections.
     Symbols in the DWARF debugging sections are relative to the beginning
     of the section so we begin them at 0.  */
  /* DWARF 1 */
  .debug          0 : { *(.debug) }
  .line           0 : { *(.line) }
  /* GNU DWARF 1 extensions */
  .debug_srcinfo  0 : { *(.debug_srcinfo) }
  .debug_sfnames  0 : { *(.debug_sfnames) }
  /* DWARF 1.1 and DWARF 2 */
  .debug_aranges  0 : { *(.debug_aranges) }
  .debug_pubnames 0 : { *(.debug_pubnames) }
  /* DWARF 2 */
  .debug_info     0 : { *(.debug_info .gnu.linkonce.wi.*) }
  .debug_abbrev   0 : { *(.debug_abbrev) }
  .debug_line     0 : { *(.debug_line) }
  .debug_frame    0 : { *(.debug_frame) }
  .debug_str      0 : { *(.debug_str) }
  .debug_loc      0 : { *(.debug_loc) }
  .debug_macinfo  0 : { *(.debug_macinfo) }
  /* SGI/MIPS DWARF 2 extensions */
  .debug_weaknames 0 : { *(.debug_weaknames) }
  .debug_funcnames 0 : { *(.debug_funcnames) }
  .debug_typenames 0 : { *(.debug_typenames) }
  .debug_varnames  0 : { *(.debug_varnames) }

}


