/*
 * Startup Code for ARM
 *
 * C-Code for Initialization
 * this code intializes the .bss and .data sections.
 *
 * by: Clemens Helfmeier
 * ClemensHelfmeier {at] gmx `dot" de
 * (replace the corresponding at and dot in the email, please).
 */


extern unsigned int _data_start, _data_load_start, _data_end, _bss_start, _bss_end;
	/* the handling of the addresses is a bit complicated.
	 * gcc assumes the values by the linker are addresses (eg 0x200000) to the value they should
	 * represent.
	 * thus a simple unsigned int *pointer = _data_start; will result in loading the value
	 * at the address (0x200000). this is not what is intended to be done, we want 0x200000 in
	 * pointer - pointer should point to 0x200000.
	 * this is achived by replacing _data_start with &_data_start.
	 */

/* AT91F_Init_BSS_DATA
 * load .data from ROM to RAM
 * zero out .bss
 * The routine pretends, all addresses are 4-Byte-aligned. Insert ". = ALIGN( 4 );" before
 * the definition of the PROVIDE( ... ); statement in the linker file to achieve this.
 * this procedure is executed in System Mode
 */
void  Init_BSS_DATA( void ) {
	unsigned int *dp, *sp;
	/* load the .data section into ram: */
	dp = &_data_start;
	sp = &_data_load_start;
	while (dp < &_data_end)
		*dp++ = *sp++;
	/* zero out the .bss section */
	dp = &_bss_start;
	while (dp < &_bss_end)
		*dp++ = 0;
}

