/*
 * Startup Code for ARM
 * This file is from the startup code version for AT91SAM7Sxx.
 *
 * C-Code for Initialization
 * This code is target-specific. It is for AT91SAM7-family.
 *
 * by: Clemens Helfmeier
 * ClemensHelfmeier {at] gmx `dot" de
 * (replace the corresponding at and dot in the email, please).
 */


#include "AT91SAM7S64.h"
#define __inline extern inline
#include "lib_AT91SAM7S64.h"

#include "startup_sam7.h"

/* AT91F_InitLowLevel
 * initialize the very basic things...
 * currently this is nothing, really nothing.
 * this procedure is executed in System Mode
 */
void InitLowLevel( void ) {
	/* enable Clock for PMC */
	AT91F_PMC_CfgPMC();

	/* disable the watchdog */
	AT91C_BASE_WDTC->WDTC_WDMR = AT91C_SYSC_WDDIS;

	/* start the embedded flash controller */
	AT91F_MC_CfgPMC();

	/* set the correct Flash Wait states */
	AT91C_BASE_MC->MC_FMR = ((FLASH_WAIT_STATES<<8) & AT91C_MC_FWS_3FWS) | (((F_CPU / 1000000)<<16) & AT91C_MC_FMCN);

	#if (OSC_EN == 1)
	/* startup the oscillator */
	/* startup time * slowclock / 8 = OSCount
	 * s[ms] * 4 = oscount
	 */
	AT91C_BASE_CKGR->CKGR_MOR = (OSC_STARTUP * 4) | AT91C_CKGR_MOSCEN;
	/* wait for oscillator ready */
	while (!(AT91C_BASE_PMC->PMC_SR & AT91C_PMC_MOSCS));

	/* optional: read the frequency */
	/* if (AT91C_BASE_CKGR->CKGR_MCFR & AT91C_CKGR_MAINRDY)
		Frequency = (AT91C_BASE_CKGR->CKGR_MCFR & AT91C_CKGR_MAINF) * SCLK/16;
	*/

	#if (PLL_EN == 1)
	/* enable and configure the pll */
	AT91C_BASE_CKGR->CKGR_PLLR =
	#if ((PLL_MUL-1) * PLL_DIV > 155)
		(AT91C_CKGR_DIV & PLL_DIV) |
		(AT91C_CKGR_MUL & ((PLL_MUL-1)<<16)) |
		(AT91C_CKGR_PLLCOUNT & (PLL_COUNT<<8)) |
		AT91C_CKGR_OUT_2;
	#else
		(AT91C_CKGR_DIV & PLL_DIV) |
		(AT91C_CKGR_MUL & ((PLL_MUL-1)<<16)) |
		(AT91C_CKGR_PLLCOUNT & (PLL_COUNT<<8)) |
		AT91C_CKGR_OUT_0;
	#endif
	/* wait for the pll to lock */
	while (!(AT91C_BASE_PMC->PMC_SR & AT91C_PMC_LOCK));
	#endif
	#endif

	#if (MCK == PLLCK)
	/* select the correct clock for the processor */
	AT91C_BASE_PMC->PMC_MCKR = AT91C_PMC_CSS_PLL_CLK | ((MCK_PRES<<2) & (0x07<<2));
	#endif
	#if (MCK == OSCCK)
	AT91C_BASE_PMC->PMC_MCKR = AT91C_PMC_CSS_MAIN_CLK | ((MCK_PRES<<2) & (0x07<<2));
	#endif
	#if (MCK == SLCK)
	AT91C_BASE_PMC->PMC_MCKR = AT91C_PMC_CSS_SLOW_CLK | ((MCK_PRES<<2) & (0x07<<2));
	#endif

}

